==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1NodeSelectorTermFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeSelectorTermFluent<A extends V1NodeSelectorTermFluent<A>> extends Fluent<A>{


    public A addToMatchExpressions(int index,V1NodeSelectorRequirement item);
    public A setToMatchExpressions(int index,V1NodeSelectorRequirement item);
    public A addToMatchExpressions(V1NodeSelectorRequirement... items);
    public A addAllToMatchExpressions(Collection<V1NodeSelectorRequirement> items);
    public A removeFromMatchExpressions(V1NodeSelectorRequirement... items);
    public A removeAllFromMatchExpressions(Collection<V1NodeSelectorRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchExpressions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NodeSelectorRequirement> getMatchExpressions();
    public List<V1NodeSelectorRequirement> buildMatchExpressions();
    public V1NodeSelectorRequirement buildMatchExpression(int index);
    public V1NodeSelectorRequirement buildFirstMatchExpression();
    public V1NodeSelectorRequirement buildLastMatchExpression();
    public V1NodeSelectorRequirement buildMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public A withMatchExpressions(List<V1NodeSelectorRequirement> matchExpressions);
    public A withMatchExpressions(V1NodeSelectorRequirement... matchExpressions);
    public Boolean hasMatchExpressions();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> addNewMatchExpression();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> addNewMatchExpressionLike(V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> setNewMatchExpressionLike(int index,V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editMatchExpression(int index);
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editFirstMatchExpression();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editLastMatchExpression();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public A addToMatchFields(int index,V1NodeSelectorRequirement item);
    public A setToMatchFields(int index,V1NodeSelectorRequirement item);
    public A addToMatchFields(V1NodeSelectorRequirement... items);
    public A addAllToMatchFields(Collection<V1NodeSelectorRequirement> items);
    public A removeFromMatchFields(V1NodeSelectorRequirement... items);
    public A removeAllFromMatchFields(Collection<V1NodeSelectorRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchFields instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NodeSelectorRequirement> getMatchFields();
    public List<V1NodeSelectorRequirement> buildMatchFields();
    public V1NodeSelectorRequirement buildMatchField(int index);
    public V1NodeSelectorRequirement buildFirstMatchField();
    public V1NodeSelectorRequirement buildLastMatchField();
    public V1NodeSelectorRequirement buildMatchingMatchField(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public A withMatchFields(List<V1NodeSelectorRequirement> matchFields);
    public A withMatchFields(V1NodeSelectorRequirement... matchFields);
    public Boolean hasMatchFields();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> addNewMatchField();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> addNewMatchFieldLike(V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> setNewMatchFieldLike(int index,V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editMatchField(int index);
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editFirstMatchField();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editLastMatchField();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editMatchingMatchField(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);

    public interface MatchExpressionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorRequirementFluent<V1NodeSelectorTermFluent.MatchExpressionsNested<N>>{

        
    public N and();    public N endMatchExpression();
}
    public interface MatchFieldsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorRequirementFluent<V1NodeSelectorTermFluent.MatchFieldsNested<N>>{

        
    public N and();    public N endMatchField();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NodeSelectorTermFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeSelectorTermFluent<A extends V1NodeSelectorTermFluent<A>> extends Fluent<A>{


    public A addToMatchExpressions(int index,V1NodeSelectorRequirement item);
    public A setToMatchExpressions(int index,V1NodeSelectorRequirement item);
    public A addToMatchExpressions(V1NodeSelectorRequirement... items);
    public A addAllToMatchExpressions(Collection<V1NodeSelectorRequirement> items);
    public A removeFromMatchExpressions(V1NodeSelectorRequirement... items);
    public A removeAllFromMatchExpressions(Collection<V1NodeSelectorRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchExpressions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NodeSelectorRequirement> getMatchExpressions();
    public List<V1NodeSelectorRequirement> buildMatchExpressions();
    public V1NodeSelectorRequirement buildMatchExpression(int index);
    public V1NodeSelectorRequirement buildFirstMatchExpression();
    public V1NodeSelectorRequirement buildLastMatchExpression();
    public V1NodeSelectorRequirement buildMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public Boolean hasMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public A withMatchExpressions(List<V1NodeSelectorRequirement> matchExpressions);
    public A withMatchExpressions(V1NodeSelectorRequirement... matchExpressions);
    public Boolean hasMatchExpressions();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> addNewMatchExpression();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> addNewMatchExpressionLike(V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> setNewMatchExpressionLike(int index,V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editMatchExpression(int index);
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editFirstMatchExpression();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editLastMatchExpression();
    public V1NodeSelectorTermFluent.MatchExpressionsNested<A> editMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public A addToMatchFields(int index,V1NodeSelectorRequirement item);
    public A setToMatchFields(int index,V1NodeSelectorRequirement item);
    public A addToMatchFields(V1NodeSelectorRequirement... items);
    public A addAllToMatchFields(Collection<V1NodeSelectorRequirement> items);
    public A removeFromMatchFields(V1NodeSelectorRequirement... items);
    public A removeAllFromMatchFields(Collection<V1NodeSelectorRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchFields instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NodeSelectorRequirement> getMatchFields();
    public List<V1NodeSelectorRequirement> buildMatchFields();
    public V1NodeSelectorRequirement buildMatchField(int index);
    public V1NodeSelectorRequirement buildFirstMatchField();
    public V1NodeSelectorRequirement buildLastMatchField();
    public V1NodeSelectorRequirement buildMatchingMatchField(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public Boolean hasMatchingMatchField(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);
    public A withMatchFields(List<V1NodeSelectorRequirement> matchFields);
    public A withMatchFields(V1NodeSelectorRequirement... matchFields);
    public Boolean hasMatchFields();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> addNewMatchField();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> addNewMatchFieldLike(V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> setNewMatchFieldLike(int index,V1NodeSelectorRequirement item);
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editMatchField(int index);
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editFirstMatchField();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editLastMatchField();
    public V1NodeSelectorTermFluent.MatchFieldsNested<A> editMatchingMatchField(io.kubernetes.client.fluent.Predicate<V1NodeSelectorRequirementBuilder> predicate);

    public interface MatchExpressionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorRequirementFluent<V1NodeSelectorTermFluent.MatchExpressionsNested<N>>{

        
    public N and();    public N endMatchExpression();
}
    public interface MatchFieldsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorRequirementFluent<V1NodeSelectorTermFluent.MatchFieldsNested<N>>{

        
    public N and();    public N endMatchField();
}


}
